@@ -18,14 +18,14 @@ class Parser:
         if len(parsed_states) not in {7 , 9}:
             raise ValueError(f"Invalid number of arguments: {line}")
 
-        id = 0
+        id = int(parsed_states[0])
+        if id not in self._data[function]:
+            self._data[function][id] = {}
+
         for i in range(1, len(parsed_states)):
             if parsed_states[i] not in {"0" , "1"}:
                 raise ValueError(f"Wrong parameter value: {line}")
 
-            id = int(parsed_states[0])
-            if id not in self._data[function]:
-                self._data[function][id] = {}
             self._data[function][id][i] = int(parsed_states[i])                   
         try:
             await self._feedback.handle_subscribtion(function, id=id)
@@ -40,7 +40,7 @@ class Parser:
         id = int(parsed_states[0])
 
         if id not in self._data[function]:
-            self._data[function][id] = {}
+            self._data[function][id] = [0] * 20
         self._data[function][id][pin] = prefix
         try:
             await self._feedback.handle_subscribtion(function, id=id)
@@ -57,7 +57,7 @@ class Parser:
             self._data[function][id] = {}
         self._data[function][id][pin] = parsed_states[2]
         try:
-            await self._feedback.handle_subscribtion(function)
+            await self._feedback.handle_subscribtion(function, id, pin)
         except Exception as e:
             _LOGGER.error(f"Error subscriber {e}")
 
@@ -74,7 +74,7 @@ class Parser:
                 self._data[function][pin] = {}
             self._data[function][pin][i] = int(parsed_states[i])                   
         try:
-            await self._feedback.handle_subscribtion(function)
+            await self._feedback.handle_subscribtion(function, id, pin)
         except Exception as e:
             _LOGGER.error(f"Error subscriber {e}")
 
